!!============================================================================
! This program runs tests for the module 'gauss_quad_formulas'.
!
!   A series of subroutines are defines for testing specific parts of 
!   the module. A sequence of these routines are called in the main
!   program. The assertions are defined in the respective subroutines.
!
! Last edited: January 16th 2020.
!!==============================================================================


!!=============!
! Main program !
!!=============!================================================================
program main
  use working_precision, only: wp
  use test_utilities   , only: print_status_start
  use test_utilities   , only: print_status_done
  use test_utilities   , only: print_error_message
  use gauss_quad_formulas_mod, only: GQF_triangle_3pnt

  implicit none
  character(:), allocatable :: module_name 
  integer     , parameter   :: num_tests = 1
  integer                   :: test_nr = 1
  module_name = 'gauss_quad_formulas_mod'

  ! Call test routines
  call test_GQF_triangle_3pnt(num_tests, test_nr)
  
  !=======!=========================!==========================================!
contains  ! /\/\/\/\/\/\/\/\/\/\/\/\!/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\!
  !=======!=========================!==========================================!

!!===========!!
! Subroutines !
!!============!=================================================================
  subroutine test_GQF_triangle_3pnt(num_tests, test_nr)
    integer     , intent(in)    :: num_tests
    integer     , intent(inout) :: test_nr
    character(:), allocatable   :: test_name 
    character(len=255)          :: msg
    
    test_name = 'GQF_triangle_3pnt'
    call print_status_start(num_tests, test_nr , module_name, &
         test_name)

    if (.not. all(GQF_triangle_3pnt(1, :) == &
         [1._wp/3._wp, 2._wp/3._wp, 1._wp/6._wp, 1._wp/6._wp]) .or. &
         .not. all(GQF_triangle_3pnt(2, :) == &
         [1._wp/3._wp, 1._wp/6._wp, 2._wp/3._wp, 1._wp/6._wp]) .or. &
         .not. all(GQF_triangle_3pnt(3, :) == &
         [1._wp/3._wp, 1._wp/6._wp, 1._wp/6._wp, 2._wp/3._wp])) then
       msg = 'Quadrature formula incorrect'
       call print_error_message(module_name, test_name, msg, degree=2)
    end if
    
    call print_status_done(test_nr)
  end subroutine test_GQF_triangle_3pnt

  !!----------------------------------------------------------------------------
    
end program main
